==> redux-0.3.0.tgz: package/lib/Container.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _lodashObjectMapValues = require('lodash/object/mapValues');

var _lodashObjectMapValues2 = _interopRequireDefault(_lodashObjectMapValues);

var _lodashUtilityIdentity = require('lodash/utility/identity');

var _lodashUtilityIdentity2 = _interopRequireDefault(_lodashUtilityIdentity);

var ReduxContainer = (function (_Component) {
  function ReduxContainer(props, context) {
    _classCallCheck(this, ReduxContainer);

    _get(Object.getPrototypeOf(ReduxContainer.prototype), 'constructor', this).call(this, props, context);
    this.handleChange = this.handleChange.bind(this);
    this.update(props);
  }

  _inherits(ReduxContainer, _Component);

  _createClass(ReduxContainer, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      this.update(nextProps);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.unsubscribe();
    }
  }, {
    key: 'update',
    value: function update(props) {
      this.actions = (0, _lodashObjectMapValues2['default'])(props.actions, this.context.wrapActionCreator);
      if (this.unsubscribe) {
        this.unsubscribe();
      }

      var stores = props.stores;
      var mapState = _lodashUtilityIdentity2['default'];
      if (typeof props.stores === 'function') {
        (function () {
          var store = props.stores;
          stores = [store];
          mapState = function (state) {
            return state[store.name];
          };
        })();
      }

      this.mapState = mapState;
      this.unsubscribe = this.context.observeStores(stores, this.handleChange);
    }
  }, {
    key: 'handleChange',
    value: function handleChange(stateFromStores) {
      var nextState = this.mapState(stateFromStores);
      if (this.state) {
        this.setState(nextState);
      } else {
        this.state = nextState;
      }
    }
  }, {
    key: 'render',
    value: function render() {
      return this.props.children(_extends({}, this.actions, this.state));
    }
  }], [{
    key: 'contextTypes',
    value: {
      wrapActionCreator: _react.PropTypes.func.isRequired,
      observeStores: _react.PropTypes.func.isRequired
    },
    enumerable: true
  }, {
    key: 'propTypes',
    value: {
      children: _react.PropTypes.func.isRequired,
      actions: _react.PropTypes.object.isRequired,
      stores: _react.PropTypes.oneOfType([_react.PropTypes.func.isRequired, _react.PropTypes.arrayOf(_react.PropTypes.func.isRequired).isRequired, _react.PropTypes.object.isRequired]).isRequired
    },
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      stores: [],
      actions: {}
    },
    enumerable: true
  }]);

  return ReduxContainer;
})(_react.Component);

exports['default'] = ReduxContainer;
module.exports = exports['default'];

==> redux-0.5.0.tgz: package/lib/Container.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _lodashObjectMapValues = require('lodash/object/mapValues');

var _lodashObjectMapValues2 = _interopRequireDefault(_lodashObjectMapValues);

var _lodashUtilityIdentity = require('lodash/utility/identity');

var _lodashUtilityIdentity2 = _interopRequireDefault(_lodashUtilityIdentity);

var ReduxContainer = (function (_Component) {
  function ReduxContainer(props, context) {
    _classCallCheck(this, ReduxContainer);

    _get(Object.getPrototypeOf(ReduxContainer.prototype), 'constructor', this).call(this, props, context);
    this.handleChange = this.handleChange.bind(this);
    this.update(props);
  }

  _inherits(ReduxContainer, _Component);

  _createClass(ReduxContainer, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      this.update(nextProps);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.unsubscribe();
    }
  }, {
    key: 'update',
    value: function update(props) {
      var _context$redux = this.context.redux;
      var wrapActionCreator = _context$redux.wrapActionCreator;
      var observeStores = _context$redux.observeStores;

      this.actions = (0, _lodashObjectMapValues2['default'])(props.actions, wrapActionCreator);
      if (this.unsubscribe) {
        this.unsubscribe();
      }

      var stores = props.stores;

      var mapState = stores.length === 1 ? function (state) {
        return state[stores[0].name];
      } : _lodashUtilityIdentity2['default'];

      this.mapState = mapState;
      this.unsubscribe = observeStores(stores, this.handleChange);
    }
  }, {
    key: 'handleChange',
    value: function handleChange(stateFromStores) {
      var nextState = this.mapState(stateFromStores);
      if (this.state) {
        this.setState(nextState);
      } else {
        this.state = nextState;
      }
    }
  }, {
    key: 'render',
    value: function render() {
      return this.props.children(_extends({}, this.actions, this.state));
    }
  }], [{
    key: 'contextTypes',
    value: {
      redux: _react.PropTypes.object.isRequired
    },
    enumerable: true
  }, {
    key: 'propTypes',
    value: {
      children: _react.PropTypes.func.isRequired,
      actions: _react.PropTypes.object.isRequired,
      stores: _react.PropTypes.oneOfType([_react.PropTypes.arrayOf(_react.PropTypes.func.isRequired).isRequired]).isRequired
    },
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      stores: [],
      actions: {}
    },
    enumerable: true
  }]);

  return ReduxContainer;
})(_react.Component);

exports['default'] = ReduxContainer;
module.exports = exports['default'];
